Class: Temporalio::Client::ActivityExecutionCount

Inherits:
Object
  • Object
show all
Defined in:
lib/temporalio/client/activity_execution_count.rb

Overview

Result of a #count_activities call.

WARNING: Standalone Activities are experimental.

Defined Under Namespace

Classes: AggregationGroup

Instance Attribute Summary collapse

Instance Attribute Details

#countInteger (readonly)

Returns Approximate number of activities matching the query. If the query had a group-by clause, this is the sum of all the counts in #groups.

Returns:

  • (Integer)

    Approximate number of activities matching the query. If the query had a group-by clause, this is the sum of all the counts in #groups.



11
12
13
# File 'lib/temporalio/client/activity_execution_count.rb', line 11

def count
  @count
end

#groupsArray<AggregationGroup> (readonly)

Returns Groups if the query had a group-by clause, or empty if not.

Returns:

  • (Array<AggregationGroup>)

    Groups if the query had a group-by clause, or empty if not.



14
15
16
# File 'lib/temporalio/client/activity_execution_count.rb', line 14

def groups
  @groups
end