Class: Temporalio::Client::Interceptor::Outbound
- Inherits:
-
Object
- Object
- Temporalio::Client::Interceptor::Outbound
- Defined in:
- lib/temporalio/client/interceptor.rb
Overview
Outbound interceptor for intercepting client calls. This should be extended by users needing to intercept client actions.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#next_interceptor ⇒ Outbound
readonly
Next interceptor in the chain.
Instance Method Summary collapse
-
#backfill_schedule(input) ⇒ Object
Called for every ScheduleHandle#backfill call.
-
#cancel_activity(input) ⇒ Object
Called for every ActivityHandle#cancel call.
-
#cancel_workflow(input) ⇒ Object
Called for every WorkflowHandle#cancel call.
-
#complete_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#complete call.
-
#count_activities(input) ⇒ ActivityExecutionCount
Called for every Temporalio::Client#count_activities call.
-
#count_workflows(input) ⇒ WorkflowExecutionCount
Called for every Temporalio::Client#count_workflows call.
-
#create_schedule(input) ⇒ ScheduleHandle
Called for every Temporalio::Client#create_schedule call.
-
#delete_schedule(input) ⇒ Object
Called for every ScheduleHandle#delete call.
-
#describe_activity(input) ⇒ ActivityExecution::Description
Called for every ActivityHandle#describe call.
-
#describe_schedule(input) ⇒ Schedule::Description
Called for every ScheduleHandle#describe call.
-
#describe_workflow(input) ⇒ WorkflowExecution::Description
Called for every WorkflowHandle#describe call.
-
#fail_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#fail call.
-
#fetch_activity_outcome(input) ⇒ Api::Activity::V1::ActivityExecutionOutcome
Called by ActivityHandle#result to long-poll the activity outcome.
-
#fetch_workflow_history_events(input) ⇒ Enumerator<Api::History::V1::HistoryEvent>
Called everytime the client needs workflow history.
-
#heartbeat_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#heartbeat call.
-
#initialize(next_interceptor) ⇒ Outbound
constructor
Initialize outbound with the next interceptor in the chain.
-
#list_activities(input) ⇒ Enumerator<ActivityExecution>
Called for every Temporalio::Client#list_activities call.
-
#list_schedules(input) ⇒ Enumerator<Schedule::List::Description>
Called for every Temporalio::Client#list_schedules call.
-
#list_workflow_page(input) ⇒ Client::ListWorkflowPage
Called for every Temporalio::Client#list_workflow_page call.
-
#pause_activity(input) ⇒ Object
Called for every ActivityHandle#pause call.
-
#pause_schedule(input) ⇒ Object
Called for every ScheduleHandle#pause call.
-
#poll_workflow_update(input) ⇒ Api::Update::V1::Outcome
Called when polling for update result.
-
#query_workflow(input) ⇒ Object?
Called for every WorkflowHandle#query call.
-
#report_cancellation_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#report_cancellation call.
-
#signal_with_start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#signal_with_start_workflow.
-
#signal_workflow(input) ⇒ Object
Called for every WorkflowHandle#signal call.
-
#start_activity(input) ⇒ ActivityHandle
Called for every Temporalio::Client#start_activity and Temporalio::Client#execute_activity call.
-
#start_update_with_start_workflow(input) ⇒ WorkflowUpdateHandle
Called for every Temporalio::Client#start_update_with_start_workflow and Temporalio::Client#execute_update_with_start_workflow call.
-
#start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#start_workflow and Temporalio::Client#execute_workflow call.
-
#start_workflow_update(input) ⇒ WorkflowUpdateHandle
Called for every WorkflowHandle#start_update call.
-
#terminate_activity(input) ⇒ Object
Called for every ActivityHandle#terminate call.
-
#terminate_workflow(input) ⇒ Object
Called for every WorkflowHandle#terminate call.
-
#trigger_schedule(input) ⇒ Object
Called for every ScheduleHandle#trigger call.
-
#unpause_activity(input) ⇒ Object
Called for every ActivityHandle#unpause call.
-
#unpause_schedule(input) ⇒ Object
Called for every ScheduleHandle#unpause call.
-
#update_activity_options(input) ⇒ Api::Activity::V1::ActivityOptions
Called for every ActivityHandle#update_options call.
-
#update_schedule(input) ⇒ Object
Called for every ScheduleHandle#update call.
Constructor Details
#initialize(next_interceptor) ⇒ Outbound
Initialize outbound with the next interceptor in the chain.
375 376 377 |
# File 'lib/temporalio/client/interceptor.rb', line 375 def initialize(next_interceptor) @next_interceptor = next_interceptor end |
Instance Attribute Details
#next_interceptor ⇒ Outbound (readonly)
Returns Next interceptor in the chain.
370 371 372 |
# File 'lib/temporalio/client/interceptor.rb', line 370 def next_interceptor @next_interceptor end |
Instance Method Details
#backfill_schedule(input) ⇒ Object
Called for every ScheduleHandle#backfill call.
500 501 502 |
# File 'lib/temporalio/client/interceptor.rb', line 500 def backfill_schedule(input) next_interceptor.backfill_schedule(input) end |
#cancel_activity(input) ⇒ Object
Called for every ActivityHandle#cancel call.
594 595 596 |
# File 'lib/temporalio/client/interceptor.rb', line 594 def cancel_activity(input) next_interceptor.cancel_activity(input) end |
#cancel_workflow(input) ⇒ Object
Called for every WorkflowHandle#cancel call.
470 471 472 |
# File 'lib/temporalio/client/interceptor.rb', line 470 def cancel_workflow(input) next_interceptor.cancel_workflow(input) end |
#complete_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#complete call.
557 558 559 |
# File 'lib/temporalio/client/interceptor.rb', line 557 def complete_async_activity(input) next_interceptor.complete_async_activity(input) end |
#count_activities(input) ⇒ ActivityExecutionCount
Called for every Temporalio::Client#count_activities call.
645 646 647 |
# File 'lib/temporalio/client/interceptor.rb', line 645 def count_activities(input) next_interceptor.count_activities(input) end |
#count_workflows(input) ⇒ WorkflowExecutionCount
Called for every Temporalio::Client#count_workflows call.
416 417 418 |
# File 'lib/temporalio/client/interceptor.rb', line 416 def count_workflows(input) next_interceptor.count_workflows(input) end |
#create_schedule(input) ⇒ ScheduleHandle
Called for every Temporalio::Client#create_schedule call.
485 486 487 |
# File 'lib/temporalio/client/interceptor.rb', line 485 def create_schedule(input) next_interceptor.create_schedule(input) end |
#delete_schedule(input) ⇒ Object
Called for every ScheduleHandle#delete call.
507 508 509 |
# File 'lib/temporalio/client/interceptor.rb', line 507 def delete_schedule(input) next_interceptor.delete_schedule(input) end |
#describe_activity(input) ⇒ ActivityExecution::Description
Called for every ActivityHandle#describe call.
587 588 589 |
# File 'lib/temporalio/client/interceptor.rb', line 587 def describe_activity(input) next_interceptor.describe_activity(input) end |
#describe_schedule(input) ⇒ Schedule::Description
Called for every ScheduleHandle#describe call.
515 516 517 |
# File 'lib/temporalio/client/interceptor.rb', line 515 def describe_schedule(input) next_interceptor.describe_schedule(input) end |
#describe_workflow(input) ⇒ WorkflowExecution::Description
Called for every WorkflowHandle#describe call.
424 425 426 |
# File 'lib/temporalio/client/interceptor.rb', line 424 def describe_workflow(input) next_interceptor.describe_workflow(input) end |
#fail_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#fail call.
564 565 566 |
# File 'lib/temporalio/client/interceptor.rb', line 564 def fail_async_activity(input) next_interceptor.fail_async_activity(input) end |
#fetch_activity_outcome(input) ⇒ Api::Activity::V1::ActivityExecutionOutcome
Called by ActivityHandle#result to long-poll the activity outcome.
653 654 655 |
# File 'lib/temporalio/client/interceptor.rb', line 653 def fetch_activity_outcome(input) next_interceptor.fetch_activity_outcome(input) end |
#fetch_workflow_history_events(input) ⇒ Enumerator<Api::History::V1::HistoryEvent>
Called everytime the client needs workflow history. This includes getting the result.
432 433 434 |
# File 'lib/temporalio/client/interceptor.rb', line 432 def fetch_workflow_history_events(input) next_interceptor.fetch_workflow_history_events(input) end |
#heartbeat_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#heartbeat call.
550 551 552 |
# File 'lib/temporalio/client/interceptor.rb', line 550 def heartbeat_async_activity(input) next_interceptor.heartbeat_async_activity(input) end |
#list_activities(input) ⇒ Enumerator<ActivityExecution>
Called for every Temporalio::Client#list_activities call.
637 638 639 |
# File 'lib/temporalio/client/interceptor.rb', line 637 def list_activities(input) next_interceptor.list_activities(input) end |
#list_schedules(input) ⇒ Enumerator<Schedule::List::Description>
Called for every Temporalio::Client#list_schedules call.
493 494 495 |
# File 'lib/temporalio/client/interceptor.rb', line 493 def list_schedules(input) next_interceptor.list_schedules(input) end |
#list_workflow_page(input) ⇒ Client::ListWorkflowPage
Called for every Temporalio::Client#list_workflow_page call.
408 409 410 |
# File 'lib/temporalio/client/interceptor.rb', line 408 def list_workflow_page(input) next_interceptor.list_workflow_page(input) end |
#pause_activity(input) ⇒ Object
Called for every ActivityHandle#pause call.
WARNING: Standalone Activities are experimental.
610 611 612 |
# File 'lib/temporalio/client/interceptor.rb', line 610 def pause_activity(input) next_interceptor.pause_activity(input) end |
#pause_schedule(input) ⇒ Object
Called for every ScheduleHandle#pause call.
522 523 524 |
# File 'lib/temporalio/client/interceptor.rb', line 522 def pause_schedule(input) next_interceptor.pause_schedule(input) end |
#poll_workflow_update(input) ⇒ Api::Update::V1::Outcome
Called when polling for update result.
463 464 465 |
# File 'lib/temporalio/client/interceptor.rb', line 463 def poll_workflow_update(input) next_interceptor.poll_workflow_update(input) end |
#query_workflow(input) ⇒ Object?
Called for every WorkflowHandle#query call.
447 448 449 |
# File 'lib/temporalio/client/interceptor.rb', line 447 def query_workflow(input) next_interceptor.query_workflow(input) end |
#report_cancellation_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#report_cancellation call.
571 572 573 |
# File 'lib/temporalio/client/interceptor.rb', line 571 def report_cancellation_async_activity(input) next_interceptor.report_cancellation_async_activity(input) end |
#signal_with_start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#signal_with_start_workflow.
400 401 402 |
# File 'lib/temporalio/client/interceptor.rb', line 400 def signal_with_start_workflow(input) next_interceptor.signal_with_start_workflow(input) end |
#signal_workflow(input) ⇒ Object
Called for every WorkflowHandle#signal call.
439 440 441 |
# File 'lib/temporalio/client/interceptor.rb', line 439 def signal_workflow(input) next_interceptor.signal_workflow(input) end |
#start_activity(input) ⇒ ActivityHandle
Called for every Temporalio::Client#start_activity and Temporalio::Client#execute_activity call.
579 580 581 |
# File 'lib/temporalio/client/interceptor.rb', line 579 def start_activity(input) next_interceptor.start_activity(input) end |
#start_update_with_start_workflow(input) ⇒ WorkflowUpdateHandle
Called for every Temporalio::Client#start_update_with_start_workflow and Temporalio::Client#execute_update_with_start_workflow call.
392 393 394 |
# File 'lib/temporalio/client/interceptor.rb', line 392 def start_update_with_start_workflow(input) next_interceptor.start_update_with_start_workflow(input) end |
#start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#start_workflow and Temporalio::Client#execute_workflow call.
383 384 385 |
# File 'lib/temporalio/client/interceptor.rb', line 383 def start_workflow(input) next_interceptor.start_workflow(input) end |
#start_workflow_update(input) ⇒ WorkflowUpdateHandle
Called for every WorkflowHandle#start_update call.
455 456 457 |
# File 'lib/temporalio/client/interceptor.rb', line 455 def start_workflow_update(input) next_interceptor.start_workflow_update(input) end |
#terminate_activity(input) ⇒ Object
Called for every ActivityHandle#terminate call.
601 602 603 |
# File 'lib/temporalio/client/interceptor.rb', line 601 def terminate_activity(input) next_interceptor.terminate_activity(input) end |
#terminate_workflow(input) ⇒ Object
Called for every WorkflowHandle#terminate call.
477 478 479 |
# File 'lib/temporalio/client/interceptor.rb', line 477 def terminate_workflow(input) next_interceptor.terminate_workflow(input) end |
#trigger_schedule(input) ⇒ Object
Called for every ScheduleHandle#trigger call.
529 530 531 |
# File 'lib/temporalio/client/interceptor.rb', line 529 def trigger_schedule(input) next_interceptor.trigger_schedule(input) end |
#unpause_activity(input) ⇒ Object
Called for every ActivityHandle#unpause call.
WARNING: Standalone Activities are experimental.
619 620 621 |
# File 'lib/temporalio/client/interceptor.rb', line 619 def unpause_activity(input) next_interceptor.unpause_activity(input) end |
#unpause_schedule(input) ⇒ Object
Called for every ScheduleHandle#unpause call.
536 537 538 |
# File 'lib/temporalio/client/interceptor.rb', line 536 def unpause_schedule(input) next_interceptor.unpause_schedule(input) end |
#update_activity_options(input) ⇒ Api::Activity::V1::ActivityOptions
Called for every ActivityHandle#update_options call.
WARNING: Standalone Activities are experimental.
629 630 631 |
# File 'lib/temporalio/client/interceptor.rb', line 629 def (input) next_interceptor.(input) end |
#update_schedule(input) ⇒ Object
Called for every ScheduleHandle#update call.
543 544 545 |
# File 'lib/temporalio/client/interceptor.rb', line 543 def update_schedule(input) next_interceptor.update_schedule(input) end |