Class: Temporalio::Client::Schedule::Backfill

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Time period and policy for actions taken as if the time passed right now.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(start_at:, end_at:, overlap: nil) ⇒ Backfill

Create backfill.

Parameters:

  • start_at (Time) —

    Start of the range to evaluate the schedule in. This is exclusive.

  • end_at (Time) —

    End of the range to evaluate the schedule in. This is inclusive.

  • overlap (OverlapPolicy) (defaults to: nil) —

    Overlap policy.



376
377
378
379
380
381
382
# File 'lib/temporalio/client/schedule.rb', line 376

def initialize(
  start_at:,
  end_at:,
  overlap: nil
)
  super
end

Instance Attribute Details

#end_at ⇒ Time

Returns End of the range to evaluate the schedule in. This is inclusive.

Returns:

  • (Time) —

    End of the range to evaluate the schedule in. This is inclusive.



370
371
372
# File 'lib/temporalio/client/schedule.rb', line 370

def end_at
  @end_at
end

#overlap ⇒ OverlapPolicy

Returns Overlap policy.

Returns:



370
371
372
# File 'lib/temporalio/client/schedule.rb', line 370

def overlap
  @overlap
end

#start_at ⇒ Time

Returns Start of the range to evaluate the schedule in. This is exclusive.

Returns:

  • (Time) —

    Start of the range to evaluate the schedule in. This is exclusive.



370
371
372
# File 'lib/temporalio/client/schedule.rb', line 370

def start_at
  @start_at
end