Class: Temporalio::Client::Schedule::Description

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Description of a schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#id ⇒ String

Returns ID of the schedule.

Returns:

  • (String) —

    ID of the schedule.



60
61
62
# File 'lib/temporalio/client/schedule.rb', line 60

def id
  @id
end

#info ⇒ Schedule::Info

Returns Information about the schedule.

Returns:



60
61
62
# File 'lib/temporalio/client/schedule.rb', line 60

def info
  @info
end

#raw_description ⇒ Api::WorkflowService::V1::DescribeScheduleResponse

Returns Raw description of the schedule.

Returns:



60
61
62
# File 'lib/temporalio/client/schedule.rb', line 60

def raw_description
  @raw_description
end

#schedule ⇒ Schedule

Returns Schedule details.

Returns:



60
61
62
# File 'lib/temporalio/client/schedule.rb', line 60

def schedule
  @schedule
end

Instance Method Details

#memo ⇒ Hash<String, Object>?

Returns Memo for the schedule, converted lazily on first call.

Returns:

  • (Hash<String, Object>, nil) —

    Memo for the schedule, converted lazily on first call.



93
94
95
# File 'lib/temporalio/client/schedule.rb', line 93

def memo
  @memo.get
end

#search_attributes ⇒ SearchAttributes?

Returns Search attributes for the schedule, converted lazily on first call.

Returns:

  • (SearchAttributes, nil) —

    Search attributes for the schedule, converted lazily on first call.



98
99
100
# File 'lib/temporalio/client/schedule.rb', line 98

def search_attributes
  @search_attributes.get
end