Class: Temporalio::Client::Schedule::Info

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Information about a schedule.

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

Returns When the schedule was created.

Returns:

  • (Time) —

    When the schedule was created.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def created_at
  @created_at
end

#last_updated_at ⇒ Time?

Returns When the schedule was last updated.

Returns:

  • (Time, nil) —

    When the schedule was last updated.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def last_updated_at
  @last_updated_at
end

#next_action_times ⇒ Array<Time>

Returns Next 10 scheduled action times.

Returns:

  • (Array<Time>) —

    Next 10 scheduled action times.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def next_action_times
  @next_action_times
end

#num_actions ⇒ Integer

Returns Number of actions taken by this schedule.

Returns:

  • (Integer) —

    Number of actions taken by this schedule.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def num_actions
  @num_actions
end

#num_actions_missed_catchup_window ⇒ Integer

Returns Number of times an action was skipped due to missing the catchup window.

Returns:

  • (Integer) —

    Number of times an action was skipped due to missing the catchup window.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def num_actions_missed_catchup_window
  @num_actions_missed_catchup_window
end

#num_actions_skipped_overlap ⇒ Integer

Returns Number of actions skipped due to overlap.

Returns:

  • (Integer) —

    Number of actions skipped due to overlap.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def num_actions_skipped_overlap
  @num_actions_skipped_overlap
end

#recent_actions ⇒ Array<ActionResult>

Returns 10 most recent actions, oldest first.

Returns:

  • (Array<ActionResult>) —

    10 most recent actions, oldest first.



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def recent_actions
  @recent_actions
end

#running_actions ⇒ Array<ActionExecution>

Returns Currently running actions.

Returns:



132
133
134
# File 'lib/temporalio/client/schedule.rb', line 132

def running_actions
  @running_actions
end