Class: Temporalio::Client::Schedule::List::Description

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Description of a listed schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#id ⇒ String

Returns ID of the schedule.

Returns:

  • (String) —

    ID of the schedule.



886
887
888
# File 'lib/temporalio/client/schedule.rb', line 886

def id
  @id
end

#info ⇒ Info?

Returns Information about the schedule. This may not be present in older Temporal servers without advanced visibility.

Returns:

  • (Info, nil) —

    Information about the schedule. This may not be present in older Temporal servers without advanced visibility.



886
887
888
# File 'lib/temporalio/client/schedule.rb', line 886

def info
  @info
end

#raw_entry ⇒ Api::Schedule::V1::ScheduleListEntry

Returns Raw description of the schedule.

Returns:



886
887
888
# File 'lib/temporalio/client/schedule.rb', line 886

def raw_entry
  @raw_entry
end

#schedule ⇒ Schedule?

Returns Schedule details that can be mutated. This may not be present in older Temporal servers without advanced visibility.

Returns:

  • (Schedule, nil) —

    Schedule details that can be mutated. This may not be present in older Temporal servers without advanced visibility.



886
887
888
# File 'lib/temporalio/client/schedule.rb', line 886

def schedule
  @schedule
end

Instance Method Details

#memo ⇒ Hash<String, Object>?

Returns Memo for the schedule, converted lazily on first call.

Returns:

  • (Hash<String, Object>, nil) —

    Memo for the schedule, converted lazily on first call.



902
903
904
# File 'lib/temporalio/client/schedule.rb', line 902

def memo
  @memo.get
end

#search_attributes ⇒ Search attributes?

Returns Search attributes for the schedule, converted lazily on first call.

Returns:

  • (Search attributes, nil) —

    Search attributes for the schedule, converted lazily on first call.



907
908
909
# File 'lib/temporalio/client/schedule.rb', line 907

def search_attributes
  @search_attributes.get
end