Class: Temporalio::Client::Schedule::List::State

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

State of a listed schedule.

Instance Attribute Summary collapse

Instance Attribute Details

#note ⇒ String?

Returns Human readable message for the schedule. The system may overwrite this value on certain conditions like pause-on-failure.

Returns:

  • (String, nil) —

    Human readable message for the schedule. The system may overwrite this value on certain conditions like pause-on-failure.



993
994
995
# File 'lib/temporalio/client/schedule.rb', line 993

def note
  @note
end

#paused ⇒ Boolean

Returns Whether the schedule is paused.

Returns:

  • (Boolean) —

    Whether the schedule is paused.



993
994
995
# File 'lib/temporalio/client/schedule.rb', line 993

def paused
  @paused
end