Class: Temporalio::Client::Schedule::Range

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Inclusive range for a schedule match value.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#finish ⇒ Integer

Returns Inclusive end of the range. If unset or less than start, defaults to start.

Returns:

  • (Integer) —

    Inclusive end of the range. If unset or less than start, defaults to start.



677
678
679
# File 'lib/temporalio/client/schedule.rb', line 677

def finish
  @finish
end

#start ⇒ Integer

Returns Inclusive start of the range.

Returns:

  • (Integer) —

    Inclusive start of the range.



677
678
679
# File 'lib/temporalio/client/schedule.rb', line 677

def start
  @start
end

#step ⇒ Integer

Returns Step to take between each value. Defaults as 1.

Returns:

  • (Integer) —

    Step to take between each value. Defaults as 1.



677
678
679
# File 'lib/temporalio/client/schedule.rb', line 677

def step
  @step
end

Class Method Details

._original_new ⇒ Object



679
# File 'lib/temporalio/client/schedule.rb', line 679

alias _original_new new

.new(start, finish = [0, start].max, step = 1) ⇒ Object

Create inclusive range.

Parameters:

  • start (Integer) —

    Inclusive start of the range.

  • finish (Integer) (defaults to: [0, start].max) —

    Inclusive end of the range. If unset or less than start, defaults to start.

  • step (Integer) (defaults to: 1) —

    Step to take between each value. Defaults as 1.



686
687
688
689
690
691
692
# File 'lib/temporalio/client/schedule.rb', line 686

def new(start, finish = [0, start].max, step = 1)
  _original_new( # steep:ignore
    start:,
    finish:,
    step:
  )
end