Class: Temporalio::Client::Schedule::Spec::Calendar

Inherits:
Data
  • Object
show all
Defined in:
lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb

Overview

Specification relative to calendar time when to run an action.

A timestamp matches if at least one range of each field matches except for year. If year is missing, that means all years match. For all fields besides year, at least one range must be present to match anything.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(second: [Range.new(0)], minute: [Range.new(0)], hour: [Range.new(0)], day_of_month: [Range.new(1, 31)], month: [Range.new(1, 12)], year: [], day_of_week: [Range.new(0, 6)], comment: nil) ⇒ Calendar

Create a calendar spec.



595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/temporalio/client/schedule.rb', line 595

def initialize(
  second: [Range.new(0)],
  minute: [Range.new(0)],
  hour: [Range.new(0)],
  day_of_month: [Range.new(1, 31)],
  month: [Range.new(1, 12)],
  year: [],
  day_of_week: [Range.new(0, 6)],
  comment: nil
)
  super
end

Instance Attribute Details

#comment ⇒ String?



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def comment
  @comment
end

#day_of_month ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def day_of_month
  @day_of_month
end

#day_of_week ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def day_of_week
  @day_of_week
end

#hour ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def hour
  @hour
end

#minute ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def minute
  @minute
end

#month ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def month
  @month
end

#second ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def second
  @second
end

#year ⇒ Array<Range>



538
539
540
# File 'lib/temporalio/client/schedule.rb', line 538

def year
  @year
end