Method: Temporalio::Client#list_schedules

Defined in:
lib/temporalio/client.rb

#list_schedules(query = nil, rpc_options: nil) ⇒ Enumerator<Schedule::List::Description>

List schedules.

Note, this list is eventually consistent. Therefore if a schedule is added or deleted, it may not be available in the list immediately.

Parameters:

  • query (String) (defaults to: nil)

    A Temporal visibility list filter.

  • rpc_options (RPCOptions, nil) (defaults to: nil)

    Advanced RPC options.

Returns:

Raises:

See Also:



716
717
718
# File 'lib/temporalio/client.rb', line 716

def list_schedules(query = nil, rpc_options: nil)
  @impl.list_schedules(Interceptor::ListSchedulesInput.new(query:, rpc_options:))
end