Class: Temporalio::Workflow::Info

Inherits:
Struct
  • Object
show all
Defined in:
lib/temporalio/workflow/info.rb,
lib/temporalio/workflow/info.rb

Overview

Note:

WARNING: This class may have required parameters added to its constructor. Users should not instantiate this class or it may break in incompatible ways.

Defined Under Namespace

Classes: ParentInfo, RootInfo

Instance Attribute Summary collapse

Instance Attribute Details

#attempt ⇒ Object

Returns the value of attribute attempt



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def attempt
  @attempt
end

#continued_run_id ⇒ Object

Returns the value of attribute continued_run_id



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def continued_run_id
  @continued_run_id
end

#cron_schedule ⇒ Object

Returns the value of attribute cron_schedule



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def cron_schedule
  @cron_schedule
end

#execution_timeout ⇒ Object

Returns the value of attribute execution_timeout



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def execution_timeout
  @execution_timeout
end

#first_execution_run_id ⇒ Object

Returns the value of attribute first_execution_run_id



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def first_execution_run_id
  @first_execution_run_id
end

#has_last_result? ⇒ Object

Returns the value of attribute has_last_result?



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def has_last_result?
  @has_last_result?
end

#headers ⇒ Object

Returns the value of attribute headers



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def headers
  @headers
end

#last_failure ⇒ Object

Returns the value of attribute last_failure



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def last_failure
  @last_failure
end

#last_result ⇒ Object

Returns the value of attribute last_result



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def last_result
  @last_result
end

#namespace ⇒ String



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def namespace
  @namespace
end

#parent ⇒ ParentInfo?



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def parent
  @parent
end

#priority ⇒ Priority



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def priority
  @priority
end

#retry_policy ⇒ RetryPolicy?



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def retry_policy
  @retry_policy
end

#root ⇒ RootInfo?



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def root
  @root
end

#run_id ⇒ String



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def run_id
  @run_id
end

#run_timeout ⇒ Float?



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def run_timeout
  @run_timeout
end

#start_time ⇒ Time



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def start_time
  @start_time
end

#task_queue ⇒ String



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def task_queue
  @task_queue
end

#task_timeout ⇒ Float



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def task_timeout
  @task_timeout
end

#workflow_id ⇒ String



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def workflow_id
  @workflow_id
end

#workflow_type ⇒ String



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def workflow_type
  @workflow_type
end