Class: Temporalio::Workflow::Info::ParentInfo

Inherits:
Struct
  • Object
show all
Defined in:
lib/temporalio/workflow/info.rb

Overview

Note:

WARNING: This class may have required parameters added to its constructor. Users should not instantiate this class or it may break in incompatible ways.

Information about a parent of a workflow.

Instance Attribute Summary collapse

Instance Attribute Details

#namespace ⇒ String

Returns Namespace for the parent.

Returns:

  • (String) —

    Namespace for the parent.



90
91
92
93
94
# File 'lib/temporalio/workflow/info.rb', line 90

ParentInfo = Struct.new(
  :namespace,
  :run_id,
  :workflow_id
)

#run_id ⇒ String

Returns Run ID for the parent.

Returns:

  • (String) —

    Run ID for the parent.



90
91
92
93
94
# File 'lib/temporalio/workflow/info.rb', line 90

ParentInfo = Struct.new(
  :namespace,
  :run_id,
  :workflow_id
)

#workflow_id ⇒ String

Returns Workflow ID for the parent.

Returns:

  • (String) —

    Workflow ID for the parent.



90
91
92
93
94
# File 'lib/temporalio/workflow/info.rb', line 90

ParentInfo = Struct.new(
  :namespace,
  :run_id,
  :workflow_id
)