Class: Temporalio::Workflow::Info::RootInfo

Inherits:
Struct
  • Object
show all
Defined in:
lib/temporalio/workflow/info.rb

Overview

Note:

WARNING: This class may have required parameters added to its constructor. Users should not instantiate this class or it may break in incompatible ways.

Information about a root of a workflow.

Instance Attribute Summary collapse

Instance Attribute Details

#run_id ⇒ String

Returns Run ID for the root.

Returns:

  • (String) —

    Run ID for the root.



105
106
107
108
# File 'lib/temporalio/workflow/info.rb', line 105

RootInfo = Struct.new(
  :run_id,
  :workflow_id
)

#workflow_id ⇒ String

Returns Workflow ID for the root.

Returns:

  • (String) —

    Workflow ID for the root.



105
106
107
108
# File 'lib/temporalio/workflow/info.rb', line 105

RootInfo = Struct.new(
  :run_id,
  :workflow_id
)