Class: Temporalio::Client
- Inherits:
-
Object
- Object
- Temporalio::Client
- Defined in:
- lib/temporalio/client.rb,
lib/temporalio/client/plugin.rb,
lib/temporalio/client/schedule.rb,
lib/temporalio/client/connection.rb,
lib/temporalio/client/interceptor.rb,
lib/temporalio/client/activity_handle.rb,
lib/temporalio/client/schedule_handle.rb,
lib/temporalio/client/workflow_handle.rb,
lib/temporalio/client/activity_execution.rb,
lib/temporalio/client/connection/service.rb,
lib/temporalio/client/workflow_execution.rb,
lib/temporalio/client/activity_id_reference.rb,
lib/temporalio/client/async_activity_handle.rb,
lib/temporalio/client/pending_activity_state.rb,
lib/temporalio/client/workflow_update_handle.rb,
lib/temporalio/client/connection/test_service.rb,
lib/temporalio/client/activity_execution_count.rb,
lib/temporalio/client/connection/cloud_service.rb,
lib/temporalio/client/workflow_execution_count.rb,
lib/temporalio/client/activity_execution_status.rb,
lib/temporalio/client/workflow_execution_status.rb,
lib/temporalio/client/workflow_update_wait_stage.rb,
lib/temporalio/client/connection/operator_service.rb,
lib/temporalio/client/connection/workflow_service.rb,
lib/temporalio/client/with_start_workflow_operation.rb,
lib/temporalio/client/workflow_query_reject_condition.rb
Overview
Client for accessing Temporal.
Most users will use Client.connect to connect a client. The #workflow_service method provides access to a raw gRPC client. To create another client on the same connection, like for a different namespace, #options may be used to get the options as a struct which can then be dup’d, altered, and splatted as kwargs to the constructor (e.g. Client.new(**my_options.to_h)).
Clients are thread-safe and are meant to be reused for the life of the application. They are built to work in both synchronous and asynchronous contexts. Internally they use callbacks based on Queue which means they are Fiber-compatible.
Defined Under Namespace
Modules: ActivityExecutionStatus, Interceptor, PendingActivityState, Plugin, WorkflowExecutionStatus, WorkflowQueryRejectCondition, WorkflowUpdateWaitStage Classes: ActivityExecution, ActivityExecutionCount, ActivityHandle, ActivityIDReference, AsyncActivityHandle, Connection, ListWorkflowPage, Options, RPCOptions, Schedule, ScheduleHandle, WithStartWorkflowOperation, WorkflowExecution, WorkflowExecutionCount, WorkflowHandle, WorkflowUpdateHandle
Instance Attribute Summary collapse
-
#options ⇒ Options
readonly
Frozen options for this client which has the same attributes as #initialize.
Class Method Summary collapse
Instance Method Summary collapse
-
#activity_handle(activity_id, activity_run_id: nil, result_hint: nil) ⇒ ActivityHandle
Get a handle for an existing standalone activity.
-
#async_activity_handle(task_token_or_id_reference) ⇒ AsyncActivityHandle
Get an async activity handle.
-
#connection ⇒ Connection
Underlying connection for this client.
-
#count_activities(query, rpc_options: nil) ⇒ ActivityExecutionCount
Count standalone activities matching a visibility query.
-
#count_workflows(query = nil, rpc_options: nil) ⇒ WorkflowExecutionCount
Count workflows.
-
#create_schedule(id, schedule, trigger_immediately: false, backfills: [], memo: nil, search_attributes: nil, rpc_options: nil) ⇒ ScheduleHandle
Create a schedule and return its handle.
-
#data_converter ⇒ DataConverter
Data converter used by this client.
-
#execute_activity(activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object?
Start a standalone activity execution and wait for its result.
-
#execute_update_with_start_workflow(update, *args, start_workflow_operation:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object
Start an update, possibly starting the workflow at the same time if it doesn’t exist (depending upon ID conflict policy), and wait for update result.
-
#execute_workflow(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object
Start a workflow and wait for its result.
-
#initialize(connection:, namespace:, data_converter: Converters::DataConverter.default, plugins: [], interceptors: [], logger: Logger.new($stdout, level: Logger::WARN), default_workflow_query_reject_condition: nil) ⇒ Client
constructor
Create a client from an existing connection.
-
#list_activities(query, rpc_options: nil) ⇒ Enumerator<ActivityExecution>
List standalone activities matching a visibility query.
-
#list_schedules(query = nil, rpc_options: nil) ⇒ Enumerator<Schedule::List::Description>
List schedules.
-
#list_workflow_page(query = nil, page_size: nil, next_page_token: nil, rpc_options: nil) ⇒ ListWorkflowPage
List workflows one page at a time.
-
#list_workflows(query = nil, rpc_options: nil) ⇒ Enumerator<WorkflowExecution>
List workflows.
-
#namespace ⇒ String
Namespace used in calls by this client.
-
#operator_service ⇒ Connection::OperatorService
Raw gRPC operator service.
-
#schedule_handle(id) ⇒ ScheduleHandle
Get a schedule handle to an existing schedule for the given ID.
-
#signal_with_start_workflow(signal, *args, start_workflow_operation:, arg_hints: nil, rpc_options: nil) ⇒ WorkflowHandle
Send a signal, possibly starting the workflow at the same time if it doesn’t exist.
-
#start_activity(activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ ActivityHandle
Start a standalone activity execution and return its handle.
-
#start_update_with_start_workflow(update, *args, start_workflow_operation:, wait_for_stage:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ WorkflowUpdateHandle
Start an update, possibly starting the workflow at the same time if it doesn’t exist (depending upon ID conflict policy).
-
#start_workflow(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ WorkflowHandle
Start a workflow and return its handle.
-
#workflow_handle(workflow_id, run_id: nil, first_execution_run_id: nil, result_hint: nil) ⇒ WorkflowHandle
Get a workflow handle to an existing workflow by its ID.
-
#workflow_service ⇒ Connection::WorkflowService
Raw gRPC workflow service.
Constructor Details
#initialize(connection:, namespace:, data_converter: Converters::DataConverter.default, plugins: [], interceptors: [], logger: Logger.new($stdout, level: Logger::WARN), default_workflow_query_reject_condition: nil) ⇒ Client
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/temporalio/client.rb', line 222 def initialize( connection:, namespace:, data_converter: Converters::DataConverter.default, plugins: [], interceptors: [], logger: Logger.new($stdout, level: Logger::WARN), default_workflow_query_reject_condition: nil ) @options = Options.new( connection:, namespace:, data_converter:, plugins:, interceptors:, logger:, default_workflow_query_reject_condition: ).freeze # Apply plugins Client._validate_plugins!(plugins) @options = plugins.reduce(@options) { |, plugin| plugin.configure_client() } # Initialize interceptors @impl = @options.interceptors.reverse_each.reduce( Internal::Client::Implementation.new(self) ) do |acc, int| # steep:ignore int.intercept_client(acc) end end |
Instance Attribute Details
#options ⇒ Options (readonly)
Returns Frozen options for this client which has the same attributes as #initialize.
200 201 202 |
# File 'lib/temporalio/client.rb', line 200 def @options end |
Class Method Details
.connect(target_host, namespace, api_key: nil, tls: nil, data_converter: Converters::DataConverter.default, plugins: [], interceptors: [], logger: Logger.new($stdout, level: Logger::WARN), default_workflow_query_reject_condition: nil, rpc_metadata: {}, rpc_retry: Connection::RPCRetryOptions.new, identity: "#{Process.pid}@#{Socket.gethostname}", keep_alive: Connection::KeepAliveOptions.new, http_connect_proxy: nil, runtime: Runtime.default, lazy_connect: false, dns_load_balancing: nil) ⇒ Client
Connect to Temporal server. This is a shortcut for Connection.new followed by Client.new.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/temporalio/client.rb', line 107 def self.connect( target_host, namespace, api_key: nil, tls: nil, data_converter: Converters::DataConverter.default, plugins: [], interceptors: [], logger: Logger.new($stdout, level: Logger::WARN), default_workflow_query_reject_condition: nil, rpc_metadata: {}, rpc_retry: Connection::RPCRetryOptions.new, identity: "#{Process.pid}@#{Socket.gethostname}", keep_alive: Connection::KeepAliveOptions.new, # Set to nil to disable http_connect_proxy: nil, runtime: Runtime.default, lazy_connect: false, dns_load_balancing: nil ) # Prepare connection. The connection var is needed here so it can be used in callback for plugin. base_connection = nil final_connection = nil around_connect = if plugins.any? _validate_plugins!(plugins) # For plugins, we have to do an around_connect approach with Connection where we provide a # no-return-value proc that is invoked with the built options and yields newly built options. # The connection will have been created before, but we allow plugins to return a # different/extended connection, possibly avoiding actual connection altogether. proc do |, &block| # Steep simply can't comprehend these advanced inline procs # steep:ignore:start # Root next call next_call_called = false next_call = proc do || raise 'next_call called more than once' if next_call_called next_call_called = true block&.call() base_connection end # Go backwards, building up new next_call invocations on plugins next_call = plugins.reverse_each.reduce(next_call) do |next_call, plugin| proc { || plugin.connect_client(, next_call) } end # Do call final_connection = next_call.call() # steep:ignore:end end end # Now create connection base_connection = Connection.new( target_host:, api_key:, tls:, rpc_metadata:, rpc_retry:, identity:, keep_alive:, http_connect_proxy:, runtime:, lazy_connect:, dns_load_balancing:, around_connect: # steep:ignore ) # Create client Client.new( connection: final_connection || base_connection, namespace:, data_converter:, plugins:, interceptors:, logger:, default_workflow_query_reject_condition: ) end |
Instance Method Details
#activity_handle(activity_id, activity_run_id: nil, result_hint: nil) ⇒ ActivityHandle
Get a handle for an existing standalone activity. Useful when the activity was started elsewhere (a different process, or by another client) and you have only its ID.
WARNING: Standalone Activities are experimental.
494 495 496 |
# File 'lib/temporalio/client.rb', line 494 def activity_handle(activity_id, activity_run_id: nil, result_hint: nil) ActivityHandle.new(client: self, id: activity_id, run_id: activity_run_id, result_hint:) end |
#async_activity_handle(task_token_or_id_reference) ⇒ AsyncActivityHandle
Get an async activity handle.
933 934 935 936 937 938 939 940 941 |
# File 'lib/temporalio/client.rb', line 933 def async_activity_handle(task_token_or_id_reference) if task_token_or_id_reference.is_a?(ActivityIDReference) AsyncActivityHandle.new(client: self, task_token: nil, id_reference: task_token_or_id_reference) elsif task_token_or_id_reference.is_a?(String) AsyncActivityHandle.new(client: self, task_token: task_token_or_id_reference, id_reference: nil) else raise ArgumentError, 'Must be a string task token or an ActivityIDReference' end end |
#connection ⇒ Connection
Returns Underlying connection for this client.
254 255 256 |
# File 'lib/temporalio/client.rb', line 254 def connection @options.connection end |
#count_activities(query, rpc_options: nil) ⇒ ActivityExecutionCount
Count standalone activities matching a visibility query.
WARNING: Standalone Activities are experimental.
681 682 683 |
# File 'lib/temporalio/client.rb', line 681 def count_activities(query, rpc_options: nil) @impl.count_activities(Interceptor::CountActivitiesInput.new(query:, rpc_options:)) end |
#count_workflows(query = nil, rpc_options: nil) ⇒ WorkflowExecutionCount
Count workflows.
864 865 866 |
# File 'lib/temporalio/client.rb', line 864 def count_workflows(query = nil, rpc_options: nil) @impl.count_workflows(Interceptor::CountWorkflowsInput.new(query:, rpc_options:)) end |
#create_schedule(id, schedule, trigger_immediately: false, backfills: [], memo: nil, search_attributes: nil, rpc_options: nil) ⇒ ScheduleHandle
Create a schedule and return its handle.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 |
# File 'lib/temporalio/client.rb', line 884 def create_schedule( id, schedule, trigger_immediately: false, backfills: [], memo: nil, search_attributes: nil, rpc_options: nil ) @impl.create_schedule(Interceptor::CreateScheduleInput.new( id:, schedule:, trigger_immediately:, backfills:, memo:, search_attributes:, rpc_options: )) end |
#data_converter ⇒ DataConverter
Returns Data converter used by this client.
264 265 266 |
# File 'lib/temporalio/client.rb', line 264 def data_converter @options.data_converter end |
#execute_activity(activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object?
Start a standalone activity execution and wait for its result. Shortcut for #start_activity + Temporalio::Client::ActivityHandle#result.
WARNING: Standalone Activities are experimental.
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/temporalio/client.rb', line 615 def execute_activity( activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil ) start_activity( activity, *args, id:, task_queue:, schedule_to_close_timeout:, schedule_to_start_timeout:, start_to_close_timeout:, heartbeat_timeout:, id_reuse_policy:, id_conflict_policy:, retry_policy:, search_attributes:, static_summary:, static_details:, priority:, start_delay:, arg_hints:, result_hint:, rpc_options: ).result end |
#execute_update_with_start_workflow(update, *args, start_workflow_operation:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object
Start an update, possibly starting the workflow at the same time if it doesn’t exist (depending upon ID conflict policy), and wait for update result. This is a shortcut for #start_update_with_start_workflow + Temporalio::Client::WorkflowUpdateHandle#result.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 |
# File 'lib/temporalio/client.rb', line 754 def execute_update_with_start_workflow( update, *args, start_workflow_operation:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil ) start_update_with_start_workflow( update, *args, start_workflow_operation:, wait_for_stage: WorkflowUpdateWaitStage::COMPLETED, id:, arg_hints:, result_hint:, rpc_options: ).result end |
#execute_workflow(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ Object
Start a workflow and wait for its result. This is a shortcut for #start_workflow + Temporalio::Client::WorkflowHandle#result.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/temporalio/client.rb', line 411 def execute_workflow( workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil ) start_workflow( workflow, *args, id:, task_queue:, static_summary:, static_details:, execution_timeout:, run_timeout:, task_timeout:, id_reuse_policy:, id_conflict_policy:, retry_policy:, cron_schedule:, memo:, search_attributes:, start_delay:, request_eager_start:, versioning_override:, priority:, arg_hints:, result_hint:, rpc_options: ).result end |
#list_activities(query, rpc_options: nil) ⇒ Enumerator<ActivityExecution>
List standalone activities matching a visibility query.
WARNING: Standalone Activities are experimental.
668 669 670 |
# File 'lib/temporalio/client.rb', line 668 def list_activities(query, rpc_options: nil) @impl.list_activities(Interceptor::ListActivitiesInput.new(query:, rpc_options:)) end |
#list_schedules(query = nil, rpc_options: nil) ⇒ Enumerator<Schedule::List::Description>
List schedules.
Note, this list is eventually consistent. Therefore if a schedule is added or deleted, it may not be available in the list immediately.
925 926 927 |
# File 'lib/temporalio/client.rb', line 925 def list_schedules(query = nil, rpc_options: nil) @impl.list_schedules(Interceptor::ListSchedulesInput.new(query:, rpc_options:)) end |
#list_workflow_page(query = nil, page_size: nil, next_page_token: nil, rpc_options: nil) ⇒ ListWorkflowPage
List workflows one page at a time.
847 848 849 850 851 852 |
# File 'lib/temporalio/client.rb', line 847 def list_workflow_page(query = nil, page_size: nil, next_page_token: nil, rpc_options: nil) @impl.list_workflow_page(Interceptor::ListWorkflowPageInput.new(query:, next_page_token:, page_size:, rpc_options:)) end |
#list_workflows(query = nil, rpc_options: nil) ⇒ Enumerator<WorkflowExecution>
List workflows.
817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 |
# File 'lib/temporalio/client.rb', line 817 def list_workflows(query = nil, rpc_options: nil) next_page_token = nil Enumerator.new do |yielder| loop do list_workflow_page_input = Interceptor::ListWorkflowPageInput.new( query: query, rpc_options: , next_page_token: next_page_token, page_size: nil ) page = @impl.list_workflow_page(list_workflow_page_input) page.executions.each { |execution| yielder << execution } next_page_token = page.next_page_token break if (next_page_token || '').empty? end end end |
#namespace ⇒ String
Returns Namespace used in calls by this client.
259 260 261 |
# File 'lib/temporalio/client.rb', line 259 def namespace @options.namespace end |
#operator_service ⇒ Connection::OperatorService
Returns Raw gRPC operator service.
274 275 276 |
# File 'lib/temporalio/client.rb', line 274 def operator_service connection.operator_service end |
#schedule_handle(id) ⇒ ScheduleHandle
Get a schedule handle to an existing schedule for the given ID.
908 909 910 |
# File 'lib/temporalio/client.rb', line 908 def schedule_handle(id) ScheduleHandle.new(client: self, id:) end |
#signal_with_start_workflow(signal, *args, start_workflow_operation:, arg_hints: nil, rpc_options: nil) ⇒ WorkflowHandle
Send a signal, possibly starting the workflow at the same time if it doesn’t exist.
788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/temporalio/client.rb', line 788 def signal_with_start_workflow( signal, *args, start_workflow_operation:, arg_hints: nil, rpc_options: nil ) signal, defn_arg_hints = Workflow::Definition::Signal._name_and_hints_from_parameter(signal) @impl.signal_with_start_workflow( Interceptor::SignalWithStartWorkflowInput.new( signal:, args:, start_workflow_operation:, arg_hints: arg_hints || defn_arg_hints, rpc_options: ) ) end |
#start_activity(activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ ActivityHandle
Start a standalone activity execution and return its handle.
WARNING: Standalone Activities are experimental.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/temporalio/client.rb', line 532 def start_activity( activity, *args, id:, task_queue:, schedule_to_close_timeout: nil, schedule_to_start_timeout: nil, start_to_close_timeout: nil, heartbeat_timeout: nil, id_reuse_policy: ActivityIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: ActivityIDConflictPolicy::FAIL, retry_policy: nil, search_attributes: nil, static_summary: nil, static_details: nil, priority: Priority.default, start_delay: nil, arg_hints: nil, result_hint: nil, rpc_options: nil ) activity_name, defn_arg_hints, defn_result_hint = Activity::Definition::Info._type_and_hints_from_parameter(activity) @impl.start_activity(Interceptor::StartActivityInput.new( activity: activity_name, args:, activity_id: id, task_queue:, schedule_to_close_timeout:, schedule_to_start_timeout:, start_to_close_timeout:, heartbeat_timeout:, id_reuse_policy:, id_conflict_policy:, retry_policy:, search_attributes:, static_summary:, static_details:, headers: {}, priority:, start_delay:, arg_hints: arg_hints || defn_arg_hints, result_hint: result_hint || defn_result_hint, rpc_options: )) end |
#start_update_with_start_workflow(update, *args, start_workflow_operation:, wait_for_stage:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ WorkflowUpdateHandle
Start an update, possibly starting the workflow at the same time if it doesn’t exist (depending upon ID conflict policy). Note that in some cases this may fail but the workflow will still be started, and the handle can then be retrieved on the start workflow operation.
707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/temporalio/client.rb', line 707 def start_update_with_start_workflow( update, *args, start_workflow_operation:, wait_for_stage:, id: SecureRandom.uuid, arg_hints: nil, result_hint: nil, rpc_options: nil ) update, defn_arg_hints, defn_result_hint = Workflow::Definition::Update._name_and_hints_from_parameter(update) @impl.start_update_with_start_workflow( Interceptor::StartUpdateWithStartWorkflowInput.new( update_id: id, update:, args:, wait_for_stage:, start_workflow_operation:, arg_hints: arg_hints || defn_arg_hints, result_hint: result_hint || defn_result_hint, headers: {}, rpc_options: ) ) end |
#start_workflow(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil) ⇒ WorkflowHandle
Start a workflow and return its handle.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/temporalio/client.rb', line 317 def start_workflow( workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, id_reuse_policy: WorkflowIDReusePolicy::ALLOW_DUPLICATE, id_conflict_policy: WorkflowIDConflictPolicy::UNSPECIFIED, retry_policy: nil, cron_schedule: nil, memo: nil, search_attributes: nil, start_delay: nil, request_eager_start: false, versioning_override: nil, priority: Priority.default, arg_hints: nil, result_hint: nil, rpc_options: nil ) # Take hints from definition if there is a definition workflow, defn_arg_hints, defn_result_hint = Workflow::Definition._workflow_type_and_hints_from_workflow_parameter(workflow) @impl.start_workflow(Interceptor::StartWorkflowInput.new( workflow:, args:, workflow_id: id, task_queue:, static_summary:, static_details:, execution_timeout:, run_timeout:, task_timeout:, id_reuse_policy:, id_conflict_policy:, retry_policy:, cron_schedule:, memo:, search_attributes:, start_delay:, request_eager_start:, headers: {}, versioning_override:, priority:, arg_hints: arg_hints || defn_arg_hints, result_hint: result_hint || defn_result_hint, rpc_options: )) end |
#workflow_handle(workflow_id, run_id: nil, first_execution_run_id: nil, result_hint: nil) ⇒ WorkflowHandle
Get a workflow handle to an existing workflow by its ID.
471 472 473 474 475 476 477 478 479 480 |
# File 'lib/temporalio/client.rb', line 471 def workflow_handle( workflow_id, run_id: nil, first_execution_run_id: nil, result_hint: nil ) WorkflowHandle.new( client: self, id: workflow_id, run_id:, result_run_id: run_id, first_execution_run_id:, result_hint: ) end |
#workflow_service ⇒ Connection::WorkflowService
Returns Raw gRPC workflow service.
269 270 271 |
# File 'lib/temporalio/client.rb', line 269 def workflow_service connection.workflow_service end |