Class: Temporalio::Client::Connection
- Inherits:
-
Object
- Object
- Temporalio::Client::Connection
- Defined in:
- lib/temporalio/client/connection.rb,
lib/temporalio/client/connection/service.rb,
lib/temporalio/client/connection/test_service.rb,
lib/temporalio/client/connection/cloud_service.rb,
lib/temporalio/client/connection/operator_service.rb,
lib/temporalio/client/connection/workflow_service.rb
Overview
Connection to Temporal server that is not namespace specific. Most users will use connect instead of this directly.
Defined Under Namespace
Modules: GrpcCompressionOptions Classes: CloudService, DnsLoadBalancingOptions, HTTPConnectProxyOptions, KeepAliveOptions, OperatorService, Options, RPCRetryOptions, Service, TLSOptions, TestService, WorkflowService
Instance Attribute Summary collapse
-
#cloud_service ⇒ CloudService
readonly
Raw gRPC cloud service.
-
#operator_service ⇒ OperatorService
readonly
Raw gRPC operator service.
-
#options ⇒ Options
readonly
Frozen options for this client which has the same attributes as #initialize.
-
#workflow_service ⇒ WorkflowService
readonly
Raw gRPC workflow service.
Instance Method Summary collapse
-
#api_key ⇒ String?
API key.
-
#api_key=(new_key) ⇒ Object
Set the API key for all future calls.
-
#connected? ⇒ Boolean
Whether this connection is connected.
-
#identity ⇒ String
Client identity.
-
#initialize(target_host:, api_key: nil, tls: nil, rpc_metadata: {}, rpc_retry: RPCRetryOptions.new, identity: "#{Process.pid}@#{Socket.gethostname}", keep_alive: KeepAliveOptions.new, http_connect_proxy: nil, runtime: Runtime.default, lazy_connect: false, dns_load_balancing: nil, grpc_compression: GrpcCompressionOptions::Gzip.new, around_connect: nil) ⇒ Connection
constructor
Connect to Temporal server.
-
#rpc_metadata ⇒ Hash<String, String>
RPC metadata (aka HTTP headers).
-
#rpc_metadata=(rpc_metadata) ⇒ Object
Set the RPC metadata (aka HTTP headers) for all future calls.
-
#target_host ⇒ String
Target host this connection is connected to.
Constructor Details
#initialize(target_host:, api_key: nil, tls: nil, rpc_metadata: {}, rpc_retry: RPCRetryOptions.new, identity: "#{Process.pid}@#{Socket.gethostname}", keep_alive: KeepAliveOptions.new, http_connect_proxy: nil, runtime: Runtime.default, lazy_connect: false, dns_load_balancing: nil, grpc_compression: GrpcCompressionOptions::Gzip.new, around_connect: nil) ⇒ Connection
Connect to Temporal server. Most users will use Temporalio::Client.connect instead of this directly. Parameters here match Options returned from #options by intention so options can be dup'd, altered, splatted to create a new connection.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/temporalio/client/connection.rb', line 218 def initialize( target_host:, api_key: nil, tls: nil, rpc_metadata: {}, rpc_retry: RPCRetryOptions.new, identity: "#{Process.pid}@#{Socket.gethostname}", keep_alive: KeepAliveOptions.new, http_connect_proxy: nil, runtime: Runtime.default, lazy_connect: false, dns_load_balancing: nil, grpc_compression: GrpcCompressionOptions::Gzip.new, around_connect: nil ) @options = Options.new( target_host:, api_key:, tls:, rpc_metadata:, rpc_retry:, identity:, keep_alive:, http_connect_proxy:, runtime:, lazy_connect:, dns_load_balancing:, grpc_compression: ).freeze @core_client_mutex = Mutex.new # Create core client now if not lazy, applying around_connect if present if around_connect # Technically around_connect can never run the block for whatever reason (i.e. plugin returning a mock # connection), so we don't enforce it around_connect.call(@options) do || @options = _core_client unless lazy_connect nil end else _core_client unless lazy_connect end # Create service instances @workflow_service = WorkflowService.new(self) @operator_service = OperatorService.new(self) @cloud_service = CloudService.new(self) end |
Instance Attribute Details
#cloud_service ⇒ CloudService (readonly)
Returns Raw gRPC cloud service.
184 185 186 |
# File 'lib/temporalio/client/connection.rb', line 184 def cloud_service @cloud_service end |
#operator_service ⇒ OperatorService (readonly)
Returns Raw gRPC operator service.
181 182 183 |
# File 'lib/temporalio/client/connection.rb', line 181 def operator_service @operator_service end |
#options ⇒ Options (readonly)
Returns Frozen options for this client which has the same attributes as #initialize. Note that if #api_key= or #rpc_metadata= are updated, the options object is replaced with those changes (it is not mutated in place).
175 176 177 |
# File 'lib/temporalio/client/connection.rb', line 175 def @options end |
#workflow_service ⇒ WorkflowService (readonly)
Returns Raw gRPC workflow service.
178 179 180 |
# File 'lib/temporalio/client/connection.rb', line 178 def workflow_service @workflow_service end |
Instance Method Details
#api_key ⇒ String?
Returns API key. This is a shortcut for options.api_key.
283 284 285 |
# File 'lib/temporalio/client/connection.rb', line 283 def api_key @options.api_key end |
#api_key=(new_key) ⇒ Object
Set the API key for all future calls. This also makes a new object for #options with the changes.
290 291 292 293 294 295 296 |
# File 'lib/temporalio/client/connection.rb', line 290 def api_key=(new_key) # Mutate the client if connected then mutate options @core_client_mutex.synchronize do @core_client&.update_api_key(new_key) @options = @options.with(api_key: new_key) end end |
#connected? ⇒ Boolean
Returns Whether this connection is connected. This is always true unless lazy_connect option was
originally set, in which case this will be false until the first call is made.
278 279 280 |
# File 'lib/temporalio/client/connection.rb', line 278 def connected? !@core_client.nil? end |
#identity ⇒ String
Returns Client identity.
272 273 274 |
# File 'lib/temporalio/client/connection.rb', line 272 def identity @options.identity end |
#rpc_metadata ⇒ Hash<String, String>
Returns RPC metadata (aka HTTP headers). This is a shortcut for options.rpc_metadata.
299 300 301 |
# File 'lib/temporalio/client/connection.rb', line 299 def @options. end |
#rpc_metadata=(rpc_metadata) ⇒ Object
Set the RPC metadata (aka HTTP headers) for all future calls. This also makes a new object for #options with the changes.
307 308 309 310 311 312 313 |
# File 'lib/temporalio/client/connection.rb', line 307 def () # Mutate the client if connected then mutate options @core_client_mutex.synchronize do @core_client&.() @options = @options.with(rpc_metadata: ) end end |
#target_host ⇒ String
Returns Target host this connection is connected to.
267 268 269 |
# File 'lib/temporalio/client/connection.rb', line 267 def target_host @options.target_host end |