Class: Temporalio::Client::Interceptor::Outbound
- Inherits:
-
Object
- Object
- Temporalio::Client::Interceptor::Outbound
- Defined in:
- lib/temporalio/client/interceptor.rb
Overview
Outbound interceptor for intercepting client calls. This should be extended by users needing to intercept client actions.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#next_interceptor ⇒ Outbound
readonly
Next interceptor in the chain.
Instance Method Summary collapse
-
#backfill_schedule(input) ⇒ Object
Called for every ScheduleHandle#backfill call.
-
#cancel_activity(input) ⇒ Object
Called for every ActivityHandle#cancel call.
-
#cancel_workflow(input) ⇒ Object
Called for every WorkflowHandle#cancel call.
-
#complete_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#complete call.
-
#count_activities(input) ⇒ ActivityExecutionCount
Called for every Temporalio::Client#count_activities call.
-
#count_workflows(input) ⇒ WorkflowExecutionCount
Called for every Temporalio::Client#count_workflows call.
-
#create_schedule(input) ⇒ ScheduleHandle
Called for every Temporalio::Client#create_schedule call.
-
#delete_schedule(input) ⇒ Object
Called for every ScheduleHandle#delete call.
-
#describe_activity(input) ⇒ ActivityExecution::Description
Called for every ActivityHandle#describe call.
-
#describe_schedule(input) ⇒ Schedule::Description
Called for every ScheduleHandle#describe call.
-
#describe_workflow(input) ⇒ WorkflowExecution::Description
Called for every WorkflowHandle#describe call.
-
#fail_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#fail call.
-
#fetch_activity_outcome(input) ⇒ Api::Activity::V1::ActivityExecutionOutcome
Called by ActivityHandle#result to long-poll the activity outcome.
-
#fetch_workflow_history_events(input) ⇒ Enumerator<Api::History::V1::HistoryEvent>
Called everytime the client needs workflow history.
-
#heartbeat_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#heartbeat call.
-
#initialize(next_interceptor) ⇒ Outbound
constructor
Initialize outbound with the next interceptor in the chain.
-
#list_activities(input) ⇒ Enumerator<ActivityExecution>
Called for every Temporalio::Client#list_activities call.
-
#list_schedules(input) ⇒ Enumerator<Schedule::List::Description>
Called for every Temporalio::Client#list_schedules call.
-
#list_workflow_page(input) ⇒ Client::ListWorkflowPage
Called for every Temporalio::Client#list_workflow_page call.
-
#pause_schedule(input) ⇒ Object
Called for every ScheduleHandle#pause call.
-
#poll_workflow_update(input) ⇒ Api::Update::V1::Outcome
Called when polling for update result.
-
#query_workflow(input) ⇒ Object?
Called for every WorkflowHandle#query call.
-
#report_cancellation_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#report_cancellation call.
-
#signal_with_start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#signal_with_start_workflow.
-
#signal_workflow(input) ⇒ Object
Called for every WorkflowHandle#signal call.
-
#start_activity(input) ⇒ ActivityHandle
Called for every Temporalio::Client#start_activity and Temporalio::Client#execute_activity call.
-
#start_update_with_start_workflow(input) ⇒ WorkflowUpdateHandle
Called for every Temporalio::Client#start_update_with_start_workflow and Temporalio::Client#execute_update_with_start_workflow call.
-
#start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#start_workflow and Temporalio::Client#execute_workflow call.
-
#start_workflow_update(input) ⇒ WorkflowUpdateHandle
Called for every WorkflowHandle#start_update call.
-
#terminate_activity(input) ⇒ Object
Called for every ActivityHandle#terminate call.
-
#terminate_workflow(input) ⇒ Object
Called for every WorkflowHandle#terminate call.
-
#trigger_schedule(input) ⇒ Object
Called for every ScheduleHandle#trigger call.
-
#unpause_schedule(input) ⇒ Object
Called for every ScheduleHandle#unpause call.
-
#update_schedule(input) ⇒ Object
Called for every ScheduleHandle#update call.
Constructor Details
#initialize(next_interceptor) ⇒ Outbound
Initialize outbound with the next interceptor in the chain.
352 353 354 |
# File 'lib/temporalio/client/interceptor.rb', line 352 def initialize(next_interceptor) @next_interceptor = next_interceptor end |
Instance Attribute Details
#next_interceptor ⇒ Outbound (readonly)
Returns Next interceptor in the chain.
347 348 349 |
# File 'lib/temporalio/client/interceptor.rb', line 347 def next_interceptor @next_interceptor end |
Instance Method Details
#backfill_schedule(input) ⇒ Object
Called for every ScheduleHandle#backfill call.
477 478 479 |
# File 'lib/temporalio/client/interceptor.rb', line 477 def backfill_schedule(input) next_interceptor.backfill_schedule(input) end |
#cancel_activity(input) ⇒ Object
Called for every ActivityHandle#cancel call.
WARNING: Standalone Activities are experimental.
577 578 579 |
# File 'lib/temporalio/client/interceptor.rb', line 577 def cancel_activity(input) next_interceptor.cancel_activity(input) end |
#cancel_workflow(input) ⇒ Object
Called for every WorkflowHandle#cancel call.
447 448 449 |
# File 'lib/temporalio/client/interceptor.rb', line 447 def cancel_workflow(input) next_interceptor.cancel_workflow(input) end |
#complete_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#complete call.
534 535 536 |
# File 'lib/temporalio/client/interceptor.rb', line 534 def complete_async_activity(input) next_interceptor.complete_async_activity(input) end |
#count_activities(input) ⇒ ActivityExecutionCount
Called for every Temporalio::Client#count_activities call.
WARNING: Standalone Activities are experimental.
606 607 608 |
# File 'lib/temporalio/client/interceptor.rb', line 606 def count_activities(input) next_interceptor.count_activities(input) end |
#count_workflows(input) ⇒ WorkflowExecutionCount
Called for every Temporalio::Client#count_workflows call.
393 394 395 |
# File 'lib/temporalio/client/interceptor.rb', line 393 def count_workflows(input) next_interceptor.count_workflows(input) end |
#create_schedule(input) ⇒ ScheduleHandle
Called for every Temporalio::Client#create_schedule call.
462 463 464 |
# File 'lib/temporalio/client/interceptor.rb', line 462 def create_schedule(input) next_interceptor.create_schedule(input) end |
#delete_schedule(input) ⇒ Object
Called for every ScheduleHandle#delete call.
484 485 486 |
# File 'lib/temporalio/client/interceptor.rb', line 484 def delete_schedule(input) next_interceptor.delete_schedule(input) end |
#describe_activity(input) ⇒ ActivityExecution::Description
Called for every ActivityHandle#describe call.
WARNING: Standalone Activities are experimental.
568 569 570 |
# File 'lib/temporalio/client/interceptor.rb', line 568 def describe_activity(input) next_interceptor.describe_activity(input) end |
#describe_schedule(input) ⇒ Schedule::Description
Called for every ScheduleHandle#describe call.
492 493 494 |
# File 'lib/temporalio/client/interceptor.rb', line 492 def describe_schedule(input) next_interceptor.describe_schedule(input) end |
#describe_workflow(input) ⇒ WorkflowExecution::Description
Called for every WorkflowHandle#describe call.
401 402 403 |
# File 'lib/temporalio/client/interceptor.rb', line 401 def describe_workflow(input) next_interceptor.describe_workflow(input) end |
#fail_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#fail call.
541 542 543 |
# File 'lib/temporalio/client/interceptor.rb', line 541 def fail_async_activity(input) next_interceptor.fail_async_activity(input) end |
#fetch_activity_outcome(input) ⇒ Api::Activity::V1::ActivityExecutionOutcome
Called by ActivityHandle#result to long-poll the activity outcome.
WARNING: Standalone Activities are experimental.
616 617 618 |
# File 'lib/temporalio/client/interceptor.rb', line 616 def fetch_activity_outcome(input) next_interceptor.fetch_activity_outcome(input) end |
#fetch_workflow_history_events(input) ⇒ Enumerator<Api::History::V1::HistoryEvent>
Called everytime the client needs workflow history. This includes getting the result.
409 410 411 |
# File 'lib/temporalio/client/interceptor.rb', line 409 def fetch_workflow_history_events(input) next_interceptor.fetch_workflow_history_events(input) end |
#heartbeat_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#heartbeat call.
527 528 529 |
# File 'lib/temporalio/client/interceptor.rb', line 527 def heartbeat_async_activity(input) next_interceptor.heartbeat_async_activity(input) end |
#list_activities(input) ⇒ Enumerator<ActivityExecution>
Called for every Temporalio::Client#list_activities call.
WARNING: Standalone Activities are experimental.
596 597 598 |
# File 'lib/temporalio/client/interceptor.rb', line 596 def list_activities(input) next_interceptor.list_activities(input) end |
#list_schedules(input) ⇒ Enumerator<Schedule::List::Description>
Called for every Temporalio::Client#list_schedules call.
470 471 472 |
# File 'lib/temporalio/client/interceptor.rb', line 470 def list_schedules(input) next_interceptor.list_schedules(input) end |
#list_workflow_page(input) ⇒ Client::ListWorkflowPage
Called for every Temporalio::Client#list_workflow_page call.
385 386 387 |
# File 'lib/temporalio/client/interceptor.rb', line 385 def list_workflow_page(input) next_interceptor.list_workflow_page(input) end |
#pause_schedule(input) ⇒ Object
Called for every ScheduleHandle#pause call.
499 500 501 |
# File 'lib/temporalio/client/interceptor.rb', line 499 def pause_schedule(input) next_interceptor.pause_schedule(input) end |
#poll_workflow_update(input) ⇒ Api::Update::V1::Outcome
Called when polling for update result.
440 441 442 |
# File 'lib/temporalio/client/interceptor.rb', line 440 def poll_workflow_update(input) next_interceptor.poll_workflow_update(input) end |
#query_workflow(input) ⇒ Object?
Called for every WorkflowHandle#query call.
424 425 426 |
# File 'lib/temporalio/client/interceptor.rb', line 424 def query_workflow(input) next_interceptor.query_workflow(input) end |
#report_cancellation_async_activity(input) ⇒ Object
Called for every AsyncActivityHandle#report_cancellation call.
548 549 550 |
# File 'lib/temporalio/client/interceptor.rb', line 548 def report_cancellation_async_activity(input) next_interceptor.report_cancellation_async_activity(input) end |
#signal_with_start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#signal_with_start_workflow.
377 378 379 |
# File 'lib/temporalio/client/interceptor.rb', line 377 def signal_with_start_workflow(input) next_interceptor.signal_with_start_workflow(input) end |
#signal_workflow(input) ⇒ Object
Called for every WorkflowHandle#signal call.
416 417 418 |
# File 'lib/temporalio/client/interceptor.rb', line 416 def signal_workflow(input) next_interceptor.signal_workflow(input) end |
#start_activity(input) ⇒ ActivityHandle
Called for every Temporalio::Client#start_activity and Temporalio::Client#execute_activity call.
WARNING: Standalone Activities are experimental.
558 559 560 |
# File 'lib/temporalio/client/interceptor.rb', line 558 def start_activity(input) next_interceptor.start_activity(input) end |
#start_update_with_start_workflow(input) ⇒ WorkflowUpdateHandle
Called for every Temporalio::Client#start_update_with_start_workflow and Temporalio::Client#execute_update_with_start_workflow call.
369 370 371 |
# File 'lib/temporalio/client/interceptor.rb', line 369 def start_update_with_start_workflow(input) next_interceptor.start_update_with_start_workflow(input) end |
#start_workflow(input) ⇒ WorkflowHandle
Called for every Temporalio::Client#start_workflow and Temporalio::Client#execute_workflow call.
360 361 362 |
# File 'lib/temporalio/client/interceptor.rb', line 360 def start_workflow(input) next_interceptor.start_workflow(input) end |
#start_workflow_update(input) ⇒ WorkflowUpdateHandle
Called for every WorkflowHandle#start_update call.
432 433 434 |
# File 'lib/temporalio/client/interceptor.rb', line 432 def start_workflow_update(input) next_interceptor.start_workflow_update(input) end |
#terminate_activity(input) ⇒ Object
Called for every ActivityHandle#terminate call.
WARNING: Standalone Activities are experimental.
586 587 588 |
# File 'lib/temporalio/client/interceptor.rb', line 586 def terminate_activity(input) next_interceptor.terminate_activity(input) end |
#terminate_workflow(input) ⇒ Object
Called for every WorkflowHandle#terminate call.
454 455 456 |
# File 'lib/temporalio/client/interceptor.rb', line 454 def terminate_workflow(input) next_interceptor.terminate_workflow(input) end |
#trigger_schedule(input) ⇒ Object
Called for every ScheduleHandle#trigger call.
506 507 508 |
# File 'lib/temporalio/client/interceptor.rb', line 506 def trigger_schedule(input) next_interceptor.trigger_schedule(input) end |
#unpause_schedule(input) ⇒ Object
Called for every ScheduleHandle#unpause call.
513 514 515 |
# File 'lib/temporalio/client/interceptor.rb', line 513 def unpause_schedule(input) next_interceptor.unpause_schedule(input) end |
#update_schedule(input) ⇒ Object
Called for every ScheduleHandle#update call.
520 521 522 |
# File 'lib/temporalio/client/interceptor.rb', line 520 def update_schedule(input) next_interceptor.update_schedule(input) end |