Class: Temporalio::Client::Schedule::Action::StartWorkflow
- Inherits:
-
Data
- Object
- Data
- Temporalio::Client::Schedule::Action::StartWorkflow
- Includes:
- Temporalio::Client::Schedule::Action
- Defined in:
- lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb
Overview
Schedule action to start a workflow.
Instance Attribute Summary collapse
-
#arg_hints ⇒ Array<Object>?
Converter hints for workflow arguments.
-
#args ⇒ Array<Object>
Arguments to the workflow.
-
#execution_timeout ⇒ Float?
Total workflow execution timeout in seconds including retries and continue as new.
-
#headers ⇒ Hash<String, Object>?
Headers for the workflow.
-
#id ⇒ String
Unique identifier for the workflow execution.
-
#memo ⇒ Hash<String, Object>?
Memo for the workflow.
-
#priority ⇒ Priority
Priority of the workflow.
-
#retry_policy ⇒ RetryPolicy?
Retry policy for the workflow.
-
#run_timeout ⇒ Float?
Timeout of a single workflow run in seconds.
-
#search_attributes ⇒ SearchAttributes?
Search attributes for the workflow.
-
#static_details ⇒ String?
Fixed details for this workflow execution that may appear in CLI/UI.
-
#static_summary ⇒ String?
Fixed single-line summary for this workflow execution that may appear in CLI/UI.
-
#task_queue ⇒ String
Task queue to run the workflow on.
-
#task_timeout ⇒ Float?
Timeout of a single workflow task in seconds.
-
#workflow ⇒ String
Workflow.
Class Method Summary collapse
- ._original_new ⇒ Object
-
.new(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, retry_policy: nil, memo: nil, search_attributes: nil, priority: Priority.default, arg_hints: nil, headers: nil) ⇒ Object
Create start-workflow schedule action.
Instance Attribute Details
#arg_hints ⇒ Array<Object>?
Returns Converter hints for workflow arguments. This is only user-set (e.g. on create) and is not persisted and therefore will not be set when describing a workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def arg_hints @arg_hints end |
#args ⇒ Array<Object>
Returns Arguments to the workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def args @args end |
#execution_timeout ⇒ Float?
Returns Total workflow execution timeout in seconds including retries and continue as new.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def execution_timeout @execution_timeout end |
#headers ⇒ Hash<String, Object>?
Returns Headers for the workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def headers @headers end |
#id ⇒ String
Returns Unique identifier for the workflow execution.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def id @id end |
#memo ⇒ Hash<String, Object>?
Returns Memo for the workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def memo @memo end |
#priority ⇒ Priority
Returns Priority of the workflow. This is currently experimental.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def priority @priority end |
#retry_policy ⇒ RetryPolicy?
Returns Retry policy for the workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def retry_policy @retry_policy end |
#run_timeout ⇒ Float?
Returns Timeout of a single workflow run in seconds.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def run_timeout @run_timeout end |
#search_attributes ⇒ SearchAttributes?
Returns Search attributes for the workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def search_attributes @search_attributes end |
#static_details ⇒ String?
Returns Fixed details for this workflow execution that may appear in CLI/UI. This can be in Temporal markdown format and can be multiple lines. This is a fixed value on the workflow that cannot be updated. For details that can be updated, use Workflow.current_details= within the workflow. This is currently experimental.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def static_details @static_details end |
#static_summary ⇒ String?
Returns Fixed single-line summary for this workflow execution that may appear in CLI/UI. This can be in single-line Temporal markdown format. This is currently experimental.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def static_summary @static_summary end |
#task_queue ⇒ String
Returns Task queue to run the workflow on.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def task_queue @task_queue end |
#task_timeout ⇒ Float?
Returns Timeout of a single workflow task in seconds.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def task_timeout @task_timeout end |
#workflow ⇒ String
Returns Workflow.
221 222 223 |
# File 'lib/temporalio/client/schedule.rb', line 221 def workflow @workflow end |
Class Method Details
._original_new ⇒ Object
225 |
# File 'lib/temporalio/client/schedule.rb', line 225 alias _original_new new |
.new(workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, retry_policy: nil, memo: nil, search_attributes: nil, priority: Priority.default, arg_hints: nil, headers: nil) ⇒ Object
Create start-workflow schedule action.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/temporalio/client/schedule.rb', line 248 def new( workflow, *args, id:, task_queue:, static_summary: nil, static_details: nil, execution_timeout: nil, run_timeout: nil, task_timeout: nil, retry_policy: nil, memo: nil, search_attributes: nil, priority: Priority.default, arg_hints: nil, headers: nil ) workflow, defn_arg_hints, = Workflow::Definition._workflow_type_and_hints_from_workflow_parameter(workflow) _original_new( # steep:ignore workflow:, args:, id:, task_queue:, static_summary:, static_details:, execution_timeout:, run_timeout:, task_timeout:, retry_policy:, memo:, search_attributes:, priority:, arg_hints: arg_hints || defn_arg_hints, headers: ) end |