Class: Temporalio::Client::Schedule::List::Description
- Inherits:
-
Data
- Object
- Data
- Temporalio::Client::Schedule::List::Description
- Defined in:
- lib/temporalio/client/schedule.rb,
lib/temporalio/client/schedule.rb
Overview
Description of a listed schedule.
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the schedule.
-
#info ⇒ Info?
Information about the schedule.
-
#raw_entry ⇒ Api::Schedule::V1::ScheduleListEntry
Raw description of the schedule.
-
#schedule ⇒ Schedule?
Schedule details that can be mutated.
Instance Method Summary collapse
-
#memo ⇒ Hash<String, Object>?
Memo for the schedule, converted lazily on first call.
-
#search_attributes ⇒ Search attributes?
Search attributes for the schedule, converted lazily on first call.
Instance Attribute Details
#id ⇒ String
Returns ID of the schedule.
887 888 889 |
# File 'lib/temporalio/client/schedule.rb', line 887 def id @id end |
#info ⇒ Info?
Returns Information about the schedule. This may not be present in older Temporal servers without advanced visibility.
887 888 889 |
# File 'lib/temporalio/client/schedule.rb', line 887 def info @info end |
#raw_entry ⇒ Api::Schedule::V1::ScheduleListEntry
Returns Raw description of the schedule.
887 888 889 |
# File 'lib/temporalio/client/schedule.rb', line 887 def raw_entry @raw_entry end |
#schedule ⇒ Schedule?
Returns Schedule details that can be mutated. This may not be present in older Temporal servers without advanced visibility.
887 888 889 |
# File 'lib/temporalio/client/schedule.rb', line 887 def schedule @schedule end |
Instance Method Details
#memo ⇒ Hash<String, Object>?
Returns Memo for the schedule, converted lazily on first call.
903 904 905 |
# File 'lib/temporalio/client/schedule.rb', line 903 def memo @memo.get end |
#search_attributes ⇒ Search attributes?
Returns Search attributes for the schedule, converted lazily on first call.
908 909 910 |
# File 'lib/temporalio/client/schedule.rb', line 908 def search_attributes @search_attributes.get end |