Exception: Temporalio::Workflow::ContinueAsNewError
- Defined in:
- lib/temporalio/workflow.rb
Overview
Error that is raised by a workflow out of the primary workflow method to issue a continue-as-new.
Instance Attribute Summary collapse
-
#arg_hints ⇒ Object
Returns the value of attribute arg_hints.
-
#args ⇒ Object
Returns the value of attribute args.
-
#backoff_start_interval ⇒ Object
Returns the value of attribute backoff_start_interval.
-
#headers ⇒ Object
Returns the value of attribute headers.
-
#initial_versioning_behavior ⇒ Object
Returns the value of attribute initial_versioning_behavior.
-
#memo ⇒ Object
Returns the value of attribute memo.
-
#retry_policy ⇒ Object
Returns the value of attribute retry_policy.
-
#run_timeout ⇒ Object
Returns the value of attribute run_timeout.
-
#search_attributes ⇒ Object
Returns the value of attribute search_attributes.
-
#task_queue ⇒ Object
Returns the value of attribute task_queue.
-
#task_timeout ⇒ Object
Returns the value of attribute task_timeout.
-
#workflow ⇒ Object
Returns the value of attribute workflow.
Instance Method Summary collapse
-
#initialize(*args, workflow: nil, task_queue: nil, run_timeout: nil, task_timeout: nil, backoff_start_interval: nil, retry_policy: nil, memo: nil, search_attributes: nil, arg_hints: nil, headers: {}, initial_versioning_behavior: nil) ⇒ ContinueAsNewError
constructor
Create a continue as new error.
Methods inherited from Error
Constructor Details
#initialize(*args, workflow: nil, task_queue: nil, run_timeout: nil, task_timeout: nil, backoff_start_interval: nil, retry_policy: nil, memo: nil, search_attributes: nil, arg_hints: nil, headers: {}, initial_versioning_behavior: nil) ⇒ ContinueAsNewError
Create a continue as new error.
683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/temporalio/workflow.rb', line 683 def initialize( *args, workflow: nil, task_queue: nil, run_timeout: nil, task_timeout: nil, backoff_start_interval: nil, retry_policy: nil, memo: nil, search_attributes: nil, arg_hints: nil, headers: {}, initial_versioning_behavior: nil ) super('Continue as new') @args = args @workflow = workflow @task_queue = task_queue @run_timeout = run_timeout @task_timeout = task_timeout @backoff_start_interval = backoff_start_interval @retry_policy = retry_policy @memo = memo @search_attributes = search_attributes @arg_hints = arg_hints @headers = headers @initial_versioning_behavior = initial_versioning_behavior Workflow._current.initialize_continue_as_new_error(self) end |
Instance Attribute Details
#arg_hints ⇒ Object
Returns the value of attribute arg_hints.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def arg_hints @arg_hints end |
#args ⇒ Object
Returns the value of attribute args.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def args @args end |
#backoff_start_interval ⇒ Object
Returns the value of attribute backoff_start_interval.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def backoff_start_interval @backoff_start_interval end |
#headers ⇒ Object
Returns the value of attribute headers.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def headers @headers end |
#initial_versioning_behavior ⇒ Object
Returns the value of attribute initial_versioning_behavior.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def initial_versioning_behavior @initial_versioning_behavior end |
#memo ⇒ Object
Returns the value of attribute memo.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def memo @memo end |
#retry_policy ⇒ Object
Returns the value of attribute retry_policy.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def retry_policy @retry_policy end |
#run_timeout ⇒ Object
Returns the value of attribute run_timeout.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def run_timeout @run_timeout end |
#search_attributes ⇒ Object
Returns the value of attribute search_attributes.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def search_attributes @search_attributes end |
#task_queue ⇒ Object
Returns the value of attribute task_queue.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def task_queue @task_queue end |
#task_timeout ⇒ Object
Returns the value of attribute task_timeout.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def task_timeout @task_timeout end |
#workflow ⇒ Object
Returns the value of attribute workflow.
651 652 653 |
# File 'lib/temporalio/workflow.rb', line 651 def workflow @workflow end |