Class: Temporalio::Workflow::Info

Inherits:
Struct
  • Object
show all
Defined in:
lib/temporalio/workflow/info.rb,
lib/temporalio/workflow/info.rb

Overview

Note:

WARNING: This class may have required parameters added to its constructor. Users should not instantiate this class or it may break in incompatible ways.

Defined Under Namespace

Classes: ParentInfo, RootInfo

Instance Attribute Summary collapse

Instance Attribute Details

#attempt ⇒ Object

Returns the value of attribute attempt

Returns:

  • (Object) —

    the current value of attempt



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def attempt
  @attempt
end

#continued_run_id ⇒ Object

Returns the value of attribute continued_run_id

Returns:

  • (Object) —

    the current value of continued_run_id



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def continued_run_id
  @continued_run_id
end

#cron_schedule ⇒ Object

Returns the value of attribute cron_schedule

Returns:

  • (Object) —

    the current value of cron_schedule



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def cron_schedule
  @cron_schedule
end

#execution_timeout ⇒ Object

Returns the value of attribute execution_timeout

Returns:

  • (Object) —

    the current value of execution_timeout



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def execution_timeout
  @execution_timeout
end

#first_execution_run_id ⇒ Object

Returns the value of attribute first_execution_run_id

Returns:

  • (Object) —

    the current value of first_execution_run_id



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def first_execution_run_id
  @first_execution_run_id
end

#has_last_result? ⇒ Object

Returns the value of attribute has_last_result?

Returns:

  • (Object) —

    the current value of has_last_result?



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def has_last_result?
  @has_last_result?
end

#headers ⇒ Object

Returns the value of attribute headers

Returns:

  • (Object) —

    the current value of headers



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def headers
  @headers
end

#last_failure ⇒ Object

Returns the value of attribute last_failure

Returns:

  • (Object) —

    the current value of last_failure



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def last_failure
  @last_failure
end

#last_result ⇒ Object

Returns the value of attribute last_result

Returns:

  • (Object) —

    the current value of last_result



5
6
7
# File 'lib/temporalio/workflow/info.rb', line 5

def last_result
  @last_result
end

#namespace ⇒ String

Returns Namespace for the workflow.

Returns:

  • (String) —

    Namespace for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def namespace
  @namespace
end

#parent ⇒ ParentInfo?

Returns Parent information for the workflow if this is a child.

Returns:

  • (ParentInfo, nil) —

    Parent information for the workflow if this is a child.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def parent
  @parent
end

#priority ⇒ Priority

Returns The priority of this workflow.

Returns:

  • (Priority) —

    The priority of this workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def priority
  @priority
end

#retry_policy ⇒ RetryPolicy?

Returns Retry policy for the workflow.

Returns:

  • (RetryPolicy, nil) —

    Retry policy for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def retry_policy
  @retry_policy
end

#root ⇒ RootInfo?

Returns Root information for the workflow. This is nil in pre-1.27.0 server versions or if there is no root (i.e. the root is itself).

Returns:

  • (RootInfo, nil) —

    Root information for the workflow. This is nil in pre-1.27.0 server versions or if there is no root (i.e. the root is itself).



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def root
  @root
end

#run_id ⇒ String

Returns Run ID for the workflow.

Returns:

  • (String) —

    Run ID for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def run_id
  @run_id
end

#run_timeout ⇒ Float?

Returns Run timeout for the workflow.

Returns:

  • (Float, nil) —

    Run timeout for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def run_timeout
  @run_timeout
end

#start_time ⇒ Time

Returns Time when the workflow started on the server.

Returns:

  • (Time) —

    Time when the workflow started on the server.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def start_time
  @start_time
end

#task_queue ⇒ String

Returns Task queue for the workflow.

Returns:

  • (String) —

    Task queue for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def task_queue
  @task_queue
end

#task_timeout ⇒ Float

Returns Task timeout for the workflow.

Returns:

  • (Float) —

    Task timeout for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def task_timeout
  @task_timeout
end

#workflow_id ⇒ String

Returns ID for the workflow.

Returns:

  • (String) —

    ID for the workflow.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def workflow_id
  @workflow_id
end

#workflow_type ⇒ String

Returns Workflow type name.

Returns:

  • (String) —

    Workflow type name.



78
79
80
# File 'lib/temporalio/workflow/info.rb', line 78

def workflow_type
  @workflow_type
end